[FFmpeg-cvslog] r13267 - trunk/libavformat/flvdec.c

bcoudurier subversion
Fri May 23 23:47:30 CEST 2008


Author: bcoudurier
Date: Fri May 23 23:47:30 2008
New Revision: 13267

Log:
flv use 32 bit pts

Modified:
   trunk/libavformat/flvdec.c

Modified: trunk/libavformat/flvdec.c
==============================================================================
--- trunk/libavformat/flvdec.c	(original)
+++ trunk/libavformat/flvdec.c	Fri May 23 23:47:30 2008
@@ -239,7 +239,7 @@ static AVStream *create_stream(AVFormatC
     if (!st)
         return NULL;
     st->codec->codec_type = is_audio ? CODEC_TYPE_AUDIO : CODEC_TYPE_VIDEO;
-    av_set_pts_info(st, 24, 1, 1000); /* 24 bit pts in ms */
+    av_set_pts_info(st, 32, 1, 1000); /* 32 bit pts in ms */
     return st;
 }
 




More information about the ffmpeg-cvslog mailing list